Class: Google::Cloud::Redis::Cluster::V1::AutomatedBackupConfig
- Inherits:
-
Object
- Object
- Google::Cloud::Redis::Cluster::V1::AutomatedBackupConfig
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/redis/cluster/v1/cloud_redis_cluster.rb
Overview
The automated backup config for a cluster.
Defined Under Namespace
Modules: AutomatedBackupMode Classes: FixedFrequencySchedule
Instance Attribute Summary collapse
-
#automated_backup_mode ⇒ ::Google::Cloud::Redis::Cluster::V1::AutomatedBackupConfig::AutomatedBackupMode
Optional.
-
#fixed_frequency_schedule ⇒ ::Google::Cloud::Redis::Cluster::V1::AutomatedBackupConfig::FixedFrequencySchedule
Optional.
-
#retention ⇒ ::Google::Protobuf::Duration
Optional.
Instance Attribute Details
#automated_backup_mode ⇒ ::Google::Cloud::Redis::Cluster::V1::AutomatedBackupConfig::AutomatedBackupMode
Returns Optional. The automated backup mode. If the mode is disabled, the other fields will be ignored.
531 532 533 534 535 536 537 538 539 540 541 542 543 544 545 546 547 548 549 550 551 552 553 554 555 556 557 |
# File 'proto_docs/google/cloud/redis/cluster/v1/cloud_redis_cluster.rb', line 531 class AutomatedBackupConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # This schedule allows the backup to be triggered at a fixed frequency # (currently only daily is supported). # @!attribute [rw] start_time # @return [::Google::Type::TimeOfDay] # Required. The start time of every automated backup in UTC. It must be set # to the start of an hour. This field is required. class FixedFrequencySchedule include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The automated backup mode. module AutomatedBackupMode # Default value. Automated backup config is not specified. AUTOMATED_BACKUP_MODE_UNSPECIFIED = 0 # Automated backup config disabled. DISABLED = 1 # Automated backup config enabled. ENABLED = 2 end end |
#fixed_frequency_schedule ⇒ ::Google::Cloud::Redis::Cluster::V1::AutomatedBackupConfig::FixedFrequencySchedule
Returns Optional. Trigger automated backups at a fixed frequency.
531 532 533 534 535 536 537 538 539 540 541 542 543 544 545 546 547 548 549 550 551 552 553 554 555 556 557 |
# File 'proto_docs/google/cloud/redis/cluster/v1/cloud_redis_cluster.rb', line 531 class AutomatedBackupConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # This schedule allows the backup to be triggered at a fixed frequency # (currently only daily is supported). # @!attribute [rw] start_time # @return [::Google::Type::TimeOfDay] # Required. The start time of every automated backup in UTC. It must be set # to the start of an hour. This field is required. class FixedFrequencySchedule include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The automated backup mode. module AutomatedBackupMode # Default value. Automated backup config is not specified. AUTOMATED_BACKUP_MODE_UNSPECIFIED = 0 # Automated backup config disabled. DISABLED = 1 # Automated backup config enabled. ENABLED = 2 end end |
#retention ⇒ ::Google::Protobuf::Duration
Returns Optional. How long to keep automated backups before the backups are deleted. The value should be between 1 day and 365 days. If not specified, the default value is 35 days.
531 532 533 534 535 536 537 538 539 540 541 542 543 544 545 546 547 548 549 550 551 552 553 554 555 556 557 |
# File 'proto_docs/google/cloud/redis/cluster/v1/cloud_redis_cluster.rb', line 531 class AutomatedBackupConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # This schedule allows the backup to be triggered at a fixed frequency # (currently only daily is supported). # @!attribute [rw] start_time # @return [::Google::Type::TimeOfDay] # Required. The start time of every automated backup in UTC. It must be set # to the start of an hour. This field is required. class FixedFrequencySchedule include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The automated backup mode. module AutomatedBackupMode # Default value. Automated backup config is not specified. AUTOMATED_BACKUP_MODE_UNSPECIFIED = 0 # Automated backup config disabled. DISABLED = 1 # Automated backup config enabled. ENABLED = 2 end end |