Class: Google::Cloud::Redis::Cluster::V1::DiscoveryEndpoint
- Inherits:
-
Object
- Object
- Google::Cloud::Redis::Cluster::V1::DiscoveryEndpoint
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/redis/cluster/v1/cloud_redis_cluster.rb
Overview
Endpoints on each network, for Redis clients to connect to the cluster.
Instance Attribute Summary collapse
-
#address ⇒ ::String
readonly
Output only.
-
#port ⇒ ::Integer
readonly
Output only.
-
#psc_config ⇒ ::Google::Cloud::Redis::Cluster::V1::PscConfig
readonly
Output only.
Instance Attribute Details
#address ⇒ ::String (readonly)
Returns Output only. Address of the exposed Redis endpoint used by clients to connect to the service. The address could be either IP or hostname.
847 848 849 850 |
# File 'proto_docs/google/cloud/redis/cluster/v1/cloud_redis_cluster.rb', line 847 class DiscoveryEndpoint include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#port ⇒ ::Integer (readonly)
Returns Output only. The port number of the exposed Redis endpoint.
847 848 849 850 |
# File 'proto_docs/google/cloud/redis/cluster/v1/cloud_redis_cluster.rb', line 847 class DiscoveryEndpoint include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#psc_config ⇒ ::Google::Cloud::Redis::Cluster::V1::PscConfig (readonly)
Returns Output only. Customer configuration for where the endpoint is created and accessed from.
847 848 849 850 |
# File 'proto_docs/google/cloud/redis/cluster/v1/cloud_redis_cluster.rb', line 847 class DiscoveryEndpoint include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |