Class: Google::Cloud::Redis::Cluster::V1::PscAutoConnection
- Inherits:
-
Object
- Object
- Google::Cloud::Redis::Cluster::V1::PscAutoConnection
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/redis/cluster/v1/cloud_redis_cluster.rb
Overview
Details of consumer resources in a PSC connection that is created through Service Connectivity Automation.
Instance Attribute Summary collapse
-
#address ⇒ ::String
readonly
Output only.
-
#connection_type ⇒ ::Google::Cloud::Redis::Cluster::V1::ConnectionType
readonly
Output only.
-
#forwarding_rule ⇒ ::String
readonly
Output only.
-
#network ⇒ ::String
Required.
-
#project_id ⇒ ::String
Required.
-
#psc_connection_id ⇒ ::String
readonly
Output only.
-
#psc_connection_status ⇒ ::Google::Cloud::Redis::Cluster::V1::PscConnectionStatus
readonly
Output only.
-
#service_attachment ⇒ ::String
readonly
Output only.
Instance Attribute Details
#address ⇒ ::String (readonly)
Returns Output only. The IP allocated on the consumer network for the PSC forwarding rule.
959 960 961 962 |
# File 'proto_docs/google/cloud/redis/cluster/v1/cloud_redis_cluster.rb', line 959 class PscAutoConnection include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#connection_type ⇒ ::Google::Cloud::Redis::Cluster::V1::ConnectionType (readonly)
Returns Output only. Type of the PSC connection.
959 960 961 962 |
# File 'proto_docs/google/cloud/redis/cluster/v1/cloud_redis_cluster.rb', line 959 class PscAutoConnection include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#forwarding_rule ⇒ ::String (readonly)
Returns Output only. The URI of the consumer side forwarding rule. Example: projects/{projectNumOrId}/regions/us-east1/forwardingRules/{resourceId}.
959 960 961 962 |
# File 'proto_docs/google/cloud/redis/cluster/v1/cloud_redis_cluster.rb', line 959 class PscAutoConnection include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#network ⇒ ::String
Returns Required. The consumer network where the IP address resides, in the form of projects/{project_id}/global/networks/{network_id}.
959 960 961 962 |
# File 'proto_docs/google/cloud/redis/cluster/v1/cloud_redis_cluster.rb', line 959 class PscAutoConnection include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#project_id ⇒ ::String
Returns Required. The consumer project_id where the forwarding rule is created from.
959 960 961 962 |
# File 'proto_docs/google/cloud/redis/cluster/v1/cloud_redis_cluster.rb', line 959 class PscAutoConnection include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#psc_connection_id ⇒ ::String (readonly)
Returns Output only. The PSC connection id of the forwarding rule connected to the service attachment.
959 960 961 962 |
# File 'proto_docs/google/cloud/redis/cluster/v1/cloud_redis_cluster.rb', line 959 class PscAutoConnection include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#psc_connection_status ⇒ ::Google::Cloud::Redis::Cluster::V1::PscConnectionStatus (readonly)
Returns Output only. The status of the PSC connection. Please note that this value is updated periodically. Please use Private Service Connect APIs for the latest status.
959 960 961 962 |
# File 'proto_docs/google/cloud/redis/cluster/v1/cloud_redis_cluster.rb', line 959 class PscAutoConnection include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#service_attachment ⇒ ::String (readonly)
Returns Output only. The service attachment which is the target of the PSC connection, in the form of projects/{project-id}/regions/{region}/serviceAttachments/{service-attachment-id}.
959 960 961 962 |
# File 'proto_docs/google/cloud/redis/cluster/v1/cloud_redis_cluster.rb', line 959 class PscAutoConnection include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |